@@ -4,8 +4,8 @@ package IO::ReadPreProcess;
 # Read lines, process .if/.else/.fi, do .include .let .print - and more.
 # It provides IO::Handle-ish functions to slot in easily to most scripts.
 
-# Author Alain D D Williams <addw@phcomp.co.uk> March 2015, 2016, 2017 Copyright (C) the author.
-# SCCS: @(#)ReadPreProcess.pm	1.10 05/25/17 16:03:07
+# Author: Alain D D Williams <addw@phcomp.co.uk> March 2015, 2016, 2017 Copyright (C) the author.
+# SCCS: @(#)ReadPreProcess.pm	1.11 06/03/17 13:53:05
 
 use 5.006;
 use strict;
@@ -18,7 +18,7 @@ our $errstr; # Error string
 
 use Math::Expression;
 
-our $VERSION = 0.81;
+our $VERSION = 0.82;
 
 # Control directive recognised by getline():
 my %ctlDirectives = map { $_ => 1 } qw/ break case close continue do done echo else elseif elsif endswitch error eval exit
@@ -2156,32 +2156,55 @@ Note also the property C<OnError> (see above).
 
 =head1 EXAMPLES
 
-The script below sets some variables that are passed on the command line
-and then reads a file. The variables that are set can be used to control
-what it reads.
+The script below sets some variables that are passed on the command line,
+more from include files and then reads stdin.
+The variables that are set can be used to control what it reads.
 
     use IO::ReadPreProcess;
     use Getopt::Long;
+    use Math::Expression;
+
+    # One arithmetic instance so that variables are visible in all files:
+    my $ArithEnv = new Math::Expression( PermitLoops => 1, EnablePrintf => 1 );
 
     my @let = ();
+    my @includes = ();
     my $verbose = 0;
     my $help = 0;
 
-    GetOptions(help => \$help, 'let=s' => \@let, verbose => \$verbose); # and other options ...
+    # Look at command line options ... add other options here:
+    GetOptions(help => \$help, 'include=s' => \@includes, 'let=s' => \@let, verbose => \$verbose);
 
     Usage if $help;
 
-    my $fh = new IO::ReadPreProcess(Fd => \*STDIN, File => 'Standard input') or
-        die "Startup error: $IO::ReadPreProcess::errstr\n";
-
     # Evaluate all --let
     # Look like: --let='advanced := 1'
     for (@let) {
-        say "evaluating: $_" if $verbose;
+        say "Evaluating: $_" if $verbose;
         die "Invalid --let='$_'\n"
-            unless(defined $fh->{Math}->ParseToScalar($_));
+            unless(defined $ArithEnv->ParseToScalar($_));
     }
 
+    # Read all --include
+    # These must not yeild anything other than blank lines
+    # The point is that we evaluate .let, etc.
+    for my $file (@includes) {        
+        say "Including: $file" if $verbose;
+ 
+        my $inc = IO::ReadPreProcess->new(File => $file, Math => $ArithEnv, OnError => 'die', PipeOK => 1) or
+            die "$0: Opening include '$file': $IO::ReadPreProcess::errstr\n";                       
+
+        # All that is next should be empty lines
+        while (<$inc>) {
+            die "Non empty line found at $inc->{Place}\n"
+                if /\S/;
+        }
+    }
+
+    # If not stdin, maybe loop over @ARGV:
+    my $fh = new IO::ReadPreProcess(Fd => \*STDIN, File => 'Standard input', Math => $ArithEnv) or
+        die "Startup error: $IO::ReadPreProcess::errstr\n";
+
     while(<$fh>) {
 	...
 
@@ -2190,7 +2213,7 @@ what it reads.
     }
 
     # Use pre-processor variable
-    print "Sum output " . $fh->{Math}->ParseToScalar('sum') . "\n";
+    print "Sum output " . $ArithEnv->ParseToScalar('sum') . "\n";
 
 Most of the interest lies in the input:
 
@@ -2228,7 +2251,7 @@ For more examples see the test suite.
 At the end of the run you might want to do this:
 
     # Some stats, for fun:
-    say STDERR $fh->{Math}->ParseToScalar('printf("Preprocessing: lines generated %d, skipped %d. Directives %d, frames opened %d, files opened %d", _CountGen, _CountSkip, _CountDirect, _CountFrames, _CountOpen)');
+    say STDERR $ArithEnv->ParseToScalar('printf("Preprocessing: lines generated %d, skipped %d. Directives %d, frames opened %d, files opened %d", _CountGen, _CountSkip, _CountDirect, _CountFrames, _CountOpen)');
 
 =head1 SECURITY
 
